#
# spec file for package python-primp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} && 0%{?sle_version} == 150600
%define force_gcc_version 13
%endif

%{?sle15_python_module_pythons}
Name:           python-primp
Version:        0.15.0
Release:        2.1
Summary:        HTTP client that can impersonate web browsers
License:        MIT
URL:            https://github.com/deedy5/primp
Source0:        https://files.pythonhosted.org/packages/source/p/primp/primp-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module maturin >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  cmake
BuildRequires:  fdupes
%if 0%{?force_gcc_version}
BuildRequires:  gcc%{?force_gcc_version}-c++
BuildRequires:  libstdc++6-gcc%{?force_gcc_version}
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  git
BuildRequires:  llvm
BuildRequires:  openssl
BuildRequires:  python-rpm-macros

%python_subpackages

%description
The fastest python HTTP client that can impersonate web browsers, mimicking
their headers and 'TLS/JA3/JA4/HTTP2' fingerprints

%prep
%autosetup -p1 -n primp-%{version} -a1

%build
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
%if 0%{?force_gcc_version}
export C_INCLUDE_PATH=/usr/lib64/gcc/%_arch-suse-linux/%{force_gcc_version}/include
export CXX=g++-%{force_gcc_version}
export CC=gcc-%{force_gcc_version}
export DCMAKE_C_COMPILER=gcc-%{force_gcc_version}
export DCMAKE_CXX_COMPILER=g++-%{force_gcc_version}
%else
export C_INCLUDE_PATH=/usr/lib64/gcc/%_arch-suse-linux/%gcc_version/include
%endif
%pyproject_wheel

%install
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# NOTE: don't run the tests as they required access to internet by trying to
# connect to "https://httpbin.org/anything".

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/primp
%{python_sitearch}/primp-%{version}*-info

%changelog
* Tue May  6 2025 Guang Yee <gyee@suse.com>
- Use a compatible GCC and stdc++ library version for 15.6.
* Tue Apr 29 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Update to 0.15.0
  * build: remove unused dependencies
  * add random
  * implement Client.headers_update()
  * add "random" to Literal Client.IMPERSONATE, Client.IMPERSONATE_OS
  * fix(impersonate): remove okhttp_3.9, 'okhttp_3.11` from "random" variants to bypass FAILURE_ON_CLIENT_HELLO
- Update to 0.14.0
  * feat: add response.stream()
  * fix(cookies): del Client.cookies setter and getter
- Update to 0.13.0
  * refactor(response): change reponse logic
  * remove: delete dead code
  * fix: cookies logic improve
  * feat: add chrome_133, firefox_135
  * typing: improve
  * benchmark(async): add aiohttp
- Update to 0.12.0
  * refactor: move request functions to python
  * feat: add getter and setter to impersonate, impersonate_os
  * fix: remove the redirection of the Proxy-Authorization header
  * feat: add AsyncClient
  * tests: add AsyncClient tests
  * benchmark: add AsyncClient
  * ci(pytest): add pytest-asyncio
  * feat: python format + lint (ruff, mypy)
- Update to 0.11.0
  * Add impersonate_os, bump rquest to v2.0.3
- Update to 0.10.0
  * Improve get_encoding_from_content
  * files: take file paths instead of contents; post files as streams
  * [stubs] create primp.pyi
  * Enable proxy authentication during HTTP redirects
  * Use tracing crate instead of log
  * traits: small performance improvements
- Update to 0.9.0
  * Build with webpki-root-certs
  * Client: add https_only, http2_only parameters; remove http1, `http2`
  * Add trait HeadersTraits
  * Client: add [getter, setter] for auth, auth_bearer, params, headers
  * IndexMap: change ahash to foldhash
  * Client: auth + auth_bearer - remove unnecessary check
  * Client: add [getter, setter] for proxy, timeout
  * add trait CookiesTraits
  * Client: add [getter, setter] for cookies
  * utils: small performance improvements
  * response: small performance improvements
  * into() -> to_string()
  * [bugfix] POST Multipart-Encoded Files
  * optimize code
- Update to 0.8.0
  * Use env variable CA_CERT_FILE to specify the CA Certificates
  * CI: macos - rust-toolchain: stable; release - add permissions and step `Generate artifact attestation`
  * CI: [linux] - add armv7 build
  * Change content: PyBytes::new_bound PyBytes::new
  * parameters data, json - replace PyDict with PyAny
  * CI: macos - update runner (macos-12 to macos-13)
  * add env var PRIMP_PROXY
  * add env var PRIMP_CA_BUNDLE
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  * Using the `pythonize` crate to handle data and json
    parameters, and return the responce as json
  * Bump rquest to v0.27, cargo update
- update to 0.6.5:
  * Bump rquest to v0.26
  * Readme: impersonate parameter - add "chrome_130"
- update to 0.6.4:
  * ca_cert_file: updated the code to match the changes in the
    upstream package
  * Bump html2text to v0.13
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * README: impersonate - add "chrome_129", "safari_18",
    "safari_ipad_18"
- update to 0.6.2:
  * README: impersonate param - add chrome_128
* Mon Sep  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * Use Exception to raise error
  * CI: [linux] [x_86_64] - use `zig` to build for manylinux_2_17
  * params data, json: replace clone() with as_unbound()
  * recode headers
  * Remove PyException
  * README: update precompiled wheels compatibility info
* Fri Aug 23 2024 Guang Yee <gyee@suse.com>
- Version v0.6.0
  * CI: bugfix after dependencies update by @deedy5
  * Use anyhow for error handling by @deedy5
  * Improve response code by @deedy5
  * [Client]: add ca_cert_file parameter by @deedy5
  * [Utils] Recode fn json_dumps, json_loads, url_encode by @deedy5
  * [html2text] Response object: 1) add attribute text_rich
  * [logging]: send Rust log messages to Python
  * small code improvements
